@@ -1,4 +1,4 @@
-from mikud.mikud import Mikud
+from mikud.mikud import Mikud, Address, City, Street
 from mikud._version import __version__
 
 __copyright__ = 'Copyright 2022 david-lev'
